@@ -24,7 +24,11 @@
 
 #include <AkonadiCore/CollectionModifyJob>
 #include <AkonadiCore/CollectionFilterProxyModel>
+#if (QT_VERSION < QT_VERSION_CHECK(5, 10, 0))
 #include <KRecursiveFilterProxyModel>
+#else
+#include <QSortFilterProxyModel>
+#endif
 #include <QInputDialog>
 
 #include <AkonadiWidgets/CollectionRequester>
@@ -47,7 +51,6 @@
 #include <QVBoxLayout>
 #include <QHBoxLayout>
 #include <QLabel>
-#include <QTimer>
 
 KNoteCollectionDisplayProxyModel::KNoteCollectionDisplayProxyModel(QObject *parent)
     : QIdentityProxyModel(parent)
@@ -141,7 +144,12 @@ KNoteCollectionConfigWidget::KNoteCollectionConfigWidget(QWidget *parent)
 
     connect(mModel, &Akonadi::EntityTreeModel::collectionTreeFetched, this, &KNoteCollectionConfigWidget::slotCollectionsInserted);
 
+#if (QT_VERSION < QT_VERSION_CHECK(5, 10, 0))
     mCollectionFilter = new KRecursiveFilterProxyModel(this);
+#else
+    mCollectionFilter = new QSortFilterProxyModel(this);
+    mCollectionFilter->setRecursiveFiltering(true);
+#endif
     mCollectionFilter->setSourceModel(mDisplayNotifierProxyModel);
     mCollectionFilter->setDynamicSortFilter(true);
     mCollectionFilter->setFilterCaseSensitivity(Qt::CaseInsensitive);
